@@ -1,7 +1,8 @@
-from py4j.java_gateway import JavaGateway, CallbackServerParameters, GatewayParameters
 import json
 import uuid
 
+from py4j.java_gateway import JavaGateway, GatewayParameters
+
 
 class JasperReport:
     data_dir = "./jasper_reports"
