@@ -35,19 +35,6 @@ class Device(MainLoopMixin):
         MainLoopMixin.__init__(self, **kwargs)
         self.loop = kwargs.get('loop', asyncio.get_event_loop())
 
-    def run(self):
-        self.loop = asyncio.get_event_loop()
-        self.task = self.loop.create_task(self.main())
-        self.loop.run_forever()
-
-    async def stop(self):
-        await self.transport_layer.stop()
-        try:
-            self.task.cancel()
-            await self.task
-        except asyncio.CancelledError:
-            pass
-
     @classmethod
     def find_first_config(cls, config_path, class_name):
         _list = os.listdir(config_path)
@@ -66,9 +53,9 @@ class Device(MainLoopMixin):
         di = kwargs.get('di')
         config = {}
         if di is None:
-            di = cls.find_first_config('{}'.format(kwargs['path']), class_name)
+            di = cls.find_first_config(cls.get_config_dir(path=kwargs['path']), class_name)
         if di:
-            config_path = path.normpath('{0}/{1}.{2}.json'.format(kwargs['path'], class_name, di))
+            config_path = cls.get_config_path(path=kwargs['path'], device_class_name=class_name, device_id=di)
             try:
                 with open(config_path, encoding='utf-8') as file:
                     config = json.load(file)
@@ -125,12 +112,9 @@ class Device(MainLoopMixin):
                 self.set_param('/oic/d', 'piid', str(uuid4()))
 
             di = self.get_device_id()
-            if not self.get_device_id():
+            if not di:
                 di = kwargs.get('di')
-            self.set_device_id(di)
-            self.change_provisioning_state()
-            self.log = logging.getLogger('{0}:{1}'.format(self.__class__.__name__, self.get_device_id()[-5:]))
-            self.log.setLevel(getattr(logging, self.get_param('/oic/con', 'logLevel', 'error').upper()))
+                self.set_device_id(di)
             return self
         except Exception as e:
             raise ExtException(
@@ -157,7 +141,10 @@ class Device(MainLoopMixin):
             data[1].pop('/oic/mnt')
         except KeyError:
             pass
-
+        try:
+            os.mkdir(self.get_config_dir(device=self))
+        except FileExistsError:
+            pass
         try:
             with open(self.get_config_path(), 'w', encoding='utf-8') as file:
                 json.dump(data[1], file, ensure_ascii=False, indent=2)
